import { formatSnp } from '../feature/formatSnp.mjs';
import { updateDetailsFileMapConfig2 } from '../feature/updateFileMapConfig.mjs';
import { createPath } from './createPath.mjs';
import { debugFunction } from './debugFunction.mjs';
import { isFileOrFolderExists } from './isFileOrFolderExists.mjs';
import { parseJSON } from './parseJSON.mjs';
import { readFile } from './readFile.mjs';

async function scanExtraFile(config) {
    debugFunction(config.isDebug, 'start', '[INIT] scanExtraFile');
    let snpFileMapConfig = await readFile(config.snpFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    if (snpFileMapConfig.snpFileMap) {
        for (const SNPKeySuffix of config.availableSNPKeySuffix) {
            if (SNPKeySuffix === 'defaultFile') {
                continue;
            }
            for (const [realFilePath, snpPathFileSet] of Object.entries(snpFileMapConfig.snpFileMap || {})) {
                const snpSuffix = formatSnp(SNPKeySuffix, 'suffix');
                const SNPSuffixFilePath = createPath([config.snpCatalog, config.templateCatalogName, realFilePath + snpSuffix]);
                if (await isFileOrFolderExists(SNPSuffixFilePath)) {
                    const SNPSuffixFileName = createPath([realFilePath + snpSuffix]);
                    snpFileMapConfig = await updateDetailsFileMapConfig2({
                        snpFileMapConfig,
                        config,
                        operation: 'addConfigSuffixFile',
                        SNPKeySuffix,
                        SNPSuffixFileName,
                        isCreated: true,
                        path: SNPSuffixFilePath,
                        realFilePath,
                        realPath: createPath([config.projectCatalog, realFilePath]),
                        templateVersion: snpFileMapConfig.templateVersion,
                    });
                }
            }
        }
    }
    debugFunction(config.isDebug, config, '[INIT] scanExtraFile - end');
    return config;
}

export { scanExtraFile };
